import { containerless } from 'aurelia-templating';
import { PLATFORM } from 'aurelia-pal';

import {
    List,
    ListDivider
} from './list';
import {
    ListGroup,
    ListGroupSubheader
} from './list-group';
import {
    ListItem,
    ListItem2Lines,
    ListItemSeparator
} from './list-item';

export class Config {
    useContainerless() {
        [
            List,
            ListDivider,
            ListGroup,
            ListGroupSubheader,
            ListItem,
            ListItem2Lines,
            ListItemSeparator
        ].forEach(classes => Object.keys(classes).forEach(key => containerless(classes[key])));
    }

    /**
     * @param {FrameworkConfiguration} config
     */
    configure(config) {
        config.globalResources(PLATFORM.moduleName('./list'));
        config.globalResources(PLATFORM.moduleName('./list-group'));
        config.globalResources(PLATFORM.moduleName('./list-item'));
    }
}

/**
 * @param {FrameworkConfiguration} aurelia
 * @param {Function}               [callback=null]
 */
export function configure(aurelia, callback = null) {
    let config = aurelia.container.get(Config);

    if (typeof callback === 'function') {
        callback(config);
    }

    config.configure(aurelia);
}

export {
    List,
    ListDivider,
    ListGroup,
    ListGroupSubheader,
    ListItem,
    ListItem2Lines,
    ListItemSeparator
};
