import { CustomElement } from '../../../packages/core/src/index';
import { bindable, customElement, inlineView } from 'aurelia-templating';

import { requireCss } from './list';

const listGroup = `<template>
    ${requireCss}
    <div class.bind="classSet" data-mdc-id.bind="dataMDCId">
        <slot></slot>
    </div>
</template>`;

/**
 * Material Design List Group Component
 * @see https://material.io/components/web/catalog/lists/
 * @see https://material-components-web.appspot.com/list.html
 *
 * @example
 * <mdc-button style="mdc-ripple-upgraded">Button</mdc-button>
 */
@customElement('mdc-list-group')
@inlineView(listGroup)
export class ListGroup extends CustomElement {
    /**
     * @return {String}
     */
    get classSet() {
        return this.prepareClasses({ 'mdc-list-group': true });
    }
}

const listGroupSubheader = `<template>
    ${requireCss}
    <h3 class.bind="classSet" data-mdc-id.bind="dataMDCId">
        <slot></slot>
    </h3>
</template>`;

/**
 * Material Design List Group Subheader Component
 * @see https://material.io/components/web/catalog/lists/
 * @see https://material-components-web.appspot.com/list.html
 *
 * @example
 * <mdc-button style="mdc-ripple-upgraded">Button</mdc-button>
 */
@customElement('mdc-list-group-subheader')
@inlineView(listGroupSubheader)
export class ListGroupSubheader extends CustomElement {
    /**
     * @return {String}
     */
    get classSet() {
        return this.prepareClasses({ 'mdc-list-group__subheader': true });
    }
}

const listItem = `<template>
    ${requireCss}
    <li class.bind="classSet" data-mdc-id.bind="dataMDCId">
        <slot></slot>
    </li>
</template>`;
