import { CustomElement } from '../../../packages/core/src/index';
import { bindable, customElement, inlineView } from 'aurelia-templating';

import { requireCss } from './list';

const listItem = `<template>
    ${requireCss}
    <li class.bind="classSet" data-mdc-id.bind="dataMDCId">
        <slot></slot>
    </li>
</template>`;

/**
 * Material Design List Item Component
 * @see https://material.io/components/web/catalog/lists/
 * @see https://material-components-web.appspot.com/list.html
 *
 * @example
 * <mdc-button style="mdc-ripple-upgraded">Button</mdc-button>
 */
@customElement('mdc-list-item')
@inlineView(listItem)
export class ListItem extends CustomElement {
    /**
     * @return {String}
     */
    get classSet() {
        return this.prepareClasses({ 'mdc-list-item': true });
    }
}

const listItemSeparator = `<template>
    ${requireCss}
    <li class.bind="classSet" role="separator" data-mdc-id.bind="dataMDCId"></li>
</template>`;

/**
 * Material Design List Item Separator Component
 * @see https://material.io/components/web/catalog/lists/
 * @see https://material-components-web.appspot.com/list.html
 *
 * @example
 * <mdc-button style="mdc-ripple-upgraded">Button</mdc-button>
 */
@customElement('mdc-list-item-separator')
@inlineView(listItemSeparator)
export class ListItemSeparator extends ListItem {
    /**
     * @return {String}
     */
    get classSet() {
        return this.prepareClasses({ 'mdc-list-divider': true });
    }
}

const listItem2Lines = `<template>
    ${requireCss}
    <li class.bind="classSet" data-mdc-id.bind="dataMDCId">
        <span class.bind="classSetLineOne">
            <slot id="lineOne"></slot>
            <span class.bind="classSetLineTwo">
                <slot id="lineTwo"></slot>
            </span>
        </span>
    </li>
</template>`;

/**
 * Material Design List Two Lines Item Component
 * @see https://material.io/components/web/catalog/lists/
 * @see https://material-components-web.appspot.com/list.html
 *
 * @example
 * <mdc-button style="mdc-ripple-upgraded">Button</mdc-button>
 */
@customElement('mdc-list-item-two-lines')
@inlineView(listItem2Lines)
export class ListItem2Lines extends ListItem {
    /**
     * @type {String}
     */
    @bindable stylesLineOne = '';
    /**
     * @type {String}
     */
    @bindable stylesLineTwo = '';
    /**
     * @return {String}
     */
    get classSetLineOne() {
        return this.prepareClasses({ 'mdc-list-item__text': true }, 'LineOne');
    }
    /**
     * @return {String}
     */
    get classSetLineTwo() {
        return this.prepareClasses({ 'mdc-list-item__secondary-text': true }, 'LineTwo');
    }
}
