import { CustomElement } from '../../../packages/core/src/index';
import { bindable, customElement, inlineView } from 'aurelia-templating';

/**
 * @type {String}
 */
export const requireCss = '<require from="@material/list/dist/mdc.list.min.css"></require>';

const list = `<template>
    ${requireCss}
    <ul class.bind="classSet" data-mdc-id.bind="dataMDCId">
        <slot></slot>
    </ul>
</template>`;

/**
 * Material Design List Component
 * @see https://material.io/components/web/catalog/lists/
 * @see https://material-components-web.appspot.com/list.html
 *
 * @example
 * <mdc-list style="mdc-ripple-upgraded">Button</mdc-list>
 */
@customElement('mdc-list')
@inlineView(list)
export class List extends CustomElement {
    /**
     * @type {Boolean}
     */
    @bindable twoLine = false;
    /**
     * @return {String}
     */
    get classSet() {
        return this.prepareClasses({
            'mdc-list': true,
            'mdc-list--two-line': this.twoLine
        });
    }
}

const listDivider = `<template>
    ${requireCss}
    <hr class.bind="classSet" data-mdc-id.bind="dataMDCId" />
</template>`;

/**
 * MDC List
 * @see https://material.io/components/web/catalog/lists/
 * @see https://material-components-web.appspot.com/list.html
 *
 * @example
 * <mdc-button style="mdc-ripple-upgraded">Button</mdc-button>
 */
@customElement('mdc-list-divider')
@inlineView(listDivider)
export class ListDivider extends CustomElement {
    /**
     * @return {String}
     */
    get classSet() {
        return this.prepareClasses({ 'mdc-list-divider': true });
    }
}

